==> python-traitsui_6.1.3.orig.tar.gz: traitsui-6.1.3/integrationtests/ui/check_list_editor_test2.py <==
#-------------------------------------------------------------------------
#
#  CheckListEditor test case for Traits UI
#
#  Written by: David C. Morrill
#
#  Date: 06/29/2005
#
#  (c) Copyright 2005 by Enthought, Inc.
#  License: BSD Style.
#
#-------------------------------------------------------------------------

#-------------------------------------------------------------------------
#  Imports:
#-------------------------------------------------------------------------

from __future__ import absolute_import, print_function

from traits.api \
    import Enum, List, Str

from traitsui.api \
    import Handler, View, Item, CheckListEditor

#-------------------------------------------------------------------------
#  'CheckListTest' class:
#-------------------------------------------------------------------------


class CheckListTest(Handler):

    #-------------------------------------------------------------------------
    #  Trait definitions:
    #-------------------------------------------------------------------------

    value = List(editor=CheckListEditor(name='values', cols=5))
    values = List(Str)
    values_text = Str('red orange yellow green blue indigo violet')

    #-------------------------------------------------------------------------
    #  Traits view definitions:
    #-------------------------------------------------------------------------

    simple_view = View('value', 'values_text@')
    custom_view = View('value@', 'values_text@')

    #-------------------------------------------------------------------------
    #  'Initializes the object:
    #-------------------------------------------------------------------------

    def __init__(self, **traits):
        super(CheckListTest, self).__init__(**traits)
        self._values_text_changed()

    #-------------------------------------------------------------------------
    #  Event handlers:
    #-------------------------------------------------------------------------

    def _values_text_changed(self):
        self.values = self.values_text.split()

#-------------------------------------------------------------------------
#  Run the tests:
#-------------------------------------------------------------------------

if __name__ == '__main__':
    clt = CheckListTest()
    clt.configure_traits(view='simple_view')
    print('value:', clt.value)
    clt.configure_traits(view='custom_view')
    print('value:', clt.value)

==> python-traitsui_7.2.1.orig.tar.gz: traitsui-7.2.1/integrationtests/ui/check_list_editor_test2.py <==
# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in LICENSE.txt and may be redistributed only under
# the conditions described in the aforementioned license. The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
#
# Thanks for using Enthought open source!

#-------------------------------------------------------------------------
#  Imports:
#-------------------------------------------------------------------------


from traits.api \
    import Enum, List, Str

from traitsui.api \
    import Handler, View, Item, CheckListEditor

#-------------------------------------------------------------------------
#  'CheckListTest' class:
#-------------------------------------------------------------------------


class CheckListTest(Handler):

    #-------------------------------------------------------------------------
    #  Trait definitions:
    #-------------------------------------------------------------------------

    value = List(editor=CheckListEditor(name='values', cols=5))
    values = List(Str)
    values_text = Str('red orange yellow green blue indigo violet')

    #-------------------------------------------------------------------------
    #  Traits view definitions:
    #-------------------------------------------------------------------------

    simple_view = View('value', 'values_text@')
    custom_view = View('value@', 'values_text@')

    #-------------------------------------------------------------------------
    #  'Initializes the object:
    #-------------------------------------------------------------------------

    def __init__(self, **traits):
        super().__init__(**traits)
        self._values_text_changed()

    #-------------------------------------------------------------------------
    #  Event handlers:
    #-------------------------------------------------------------------------

    def _values_text_changed(self):
        self.values = self.values_text.split()

#-------------------------------------------------------------------------
#  Run the tests:
#-------------------------------------------------------------------------

if __name__ == '__main__':
    clt = CheckListTest()
    clt.configure_traits(view='simple_view')
    print('value:', clt.value)
    clt.configure_traits(view='custom_view')
    print('value:', clt.value)
